@@ -5,7 +5,7 @@ use warnings;
 use 5.010;
 use parent qw/autobox/;
 
-our $VERSION = "1.030";
+our $VERSION = "1.031";
 
 =head1 NAME
 
@@ -58,10 +58,10 @@ particular when the values are hashrefs or objects.
     $book_genres->group_array; # "Sci-fi" => [ "Sci-fi", "Sci-fi", "Sci-fi"]
 
     # Flatten arrayrefs-of-arrayrefs
-    $authors->map_by("books") # ->books returns an arrayref
-    # [ [ $book1, $book2 ], [ $book3 ] ]
-    $authors->map_by("books")->flat;
-    # [ $book1, $book2, $book3 ]
+      $authors->map_by("books") # ->books returns an arrayref
+      # [ [ $book1, $book2 ], [ $book3 ] ]
+      $authors->map_by("books")->flat;
+      # [ $book1, $book2, $book3 ]
 
     # Return reference, even in list context, e.g. in a parameter list
     $book_locations->filter()->to_ref;
@@ -76,7 +76,9 @@ particular when the values are hashrefs or objects.
 =head2 Arrays with hashrefs/objects
 
     # $books and $authors below are arrayrefs with either objects or
-    # hashrefs (the call syntax is the same)
+    # hashrefs (the call syntax is the same). These have methods/hash
+    # keys like C<$book->genre()>, C<$book->{is_sold_out}>,
+    # C<$book->is_in_library($library)>, etc.
 
     $books->map_by("genre");
     $books->map_by([ price_with_tax => $tax_pct ]);
@@ -141,7 +143,7 @@ particular when the values are hashrefs or objects.
 =head2 Hashes
 
     # map over each pair
-    # Upper-case the genre name, and make the count say "n books"
+    # e.g. Upper-case the genre name, and make the count say "n books"
     #     (return a key => value pair)
     $genre_count->map_each(sub { uc( $_[0] ) => "$_ books" });
     # {
@@ -150,7 +152,7 @@ particular when the values are hashrefs or objects.
     # },
 
     # map over each value
-    # Make the count say "n books"
+    # e.g. Make the count say "n books"
     #     (return the new value)
     $genre_count->map_each_value(sub { "$_ books" });
     # {
@@ -159,7 +161,7 @@ particular when the values are hashrefs or objects.
     # },
 
     # map each pair into an array
-    # Transform each pair to the string "n: genre"
+    # e.g. Transform each pair to the string "n: genre"
     #     (return list of items)
     $genre_count->map_each_to_array(sub { "$_: $_[0]" });
     # [ "1: Fantasy", "3: Sci-fi" ]
@@ -193,115 +195,6 @@ particular when the values are hashrefs or objects.
         ->map_by([ price_with_tax => $tax_pct ])
         ->sum;
 
-
-
-=head1 DESCRIPTION
-
-High level autobox methods you can call on arrays, arrayrefs, hashes
-and hashrefs.
-
-=over 4
-
-=item
-
-@array->filter()
-
-=item
-
-@array->order()
-
-=item
-
-@array->group()
-
-=item
-
-@array->group_count()
-
-=item
-
-@array->group_array()
-
-=item
-
-@array->flat()
-
-=item
-
-@array->to_ref()
-
-=item
-
-@array->to_array()
-
-=item
-
-@array->to_hash()
-
-=item
-
-@array->map_by()
-
-=item
-
-@array->filter_by()
-
-=item
-
-@array->uniq_by()
-
-=item
-
-@array->order_by()
-
-=item
-
-@array->group_by()
-
-=item
-
-@array->group_by_count()
-
-=item
-
-@array->group_by_array()
-
-=back
-
-
-=over 4
-
-=item
-
-%hash->map_each
-
-=item
-
-%hash->map_each_value
-
-=item
-
-%hash->map_each_to_array
-
-=item
-
-%hash->filter_each
-
-=item
-
-%hash->to_ref()
-
-=item
-
-%hash->to_hash()
-
-=item
-
-%hash->to_array()
-
-=back
-
-
 =cut
 
 
@@ -396,6 +289,12 @@ sub _predicate {
 
 
 
+=head1 DESCRIPTION
+
+High level autobox methods you can call on arrays, arrayrefs, hashes
+and hashrefs.
+
+
 =head2 Transforming lists of objects vs list of hashrefs
 
 C<map_by>, C<filter_by> C<order_by> etc. (all methods named C<*_by>)
@@ -415,21 +314,21 @@ If the array contains objects, a method is called on each object
 
 For method calls, it's possible to provide arguments to the method.
 
-Consider C<filter_by>:
+Consider C<map_by>:
 
-    $array->filter_by($accessor, $predicate)
+    $array->map_by($accessor)
 
 If the $accessor is a string, it's a simple method call.
 
     # method call without args
-    $books->filter_by("price", sub { $_ < 15.0 })
+    $books->map_by("price")
     # becomes $_->price() or $_->{price}
 
 If the $accessor is an arrayref, the first item is the method name,
 and the rest of the items are the arguments to the method.
 
     # method call with args
-    $books->filter_by([ price_with_discount => 5.0 ], sub { $_ < 15.0 })
+    $books->map_by([ price_with_discount => 5.0 ])
     # becomes $_->price_with_discount(5.0)
 
 =head3 Deprecated syntax
@@ -542,7 +441,7 @@ Provide order options for how one value should be compared with the others:
 
 =item *
 
-how to compare (C<cmp> or C<<=>>)
+how to compare (C<cmp> or C<<=E<gt>>)
 
 =item *
 
@@ -564,13 +463,13 @@ In case of a tie, provide another comparison
 
     # ->order
     @users->order(
-        sub { $_->{name} },                               # first comparison
+        sub { uc( $_->{name} ) },                         # first comparison
         [ "num", sub { int( $_->{age} / 10 ) }, "desc" ], # second comparison
     )
 
     # ->order_by
     @users->order_by(
-        name => "str",                                     # first comparison
+        name => sub { uc },                                # first comparison
         age  => [ num => desc => sub { int( $_ / 10 ) } ], # second comparison
     )
 
@@ -691,16 +590,16 @@ When the first comparison is a tie, the subsequent ones are used.
     )
 
     # order_by: pairs of accessor-comparison options
-    ->order(
+    ->order_by(
         price => "num", # First a numeric comparison of price
         name => "desc", # or if same, a reverse comparison of the name
     )
-    ->order(
+    ->order_by(
         price => [ "num", "desc" ],
         name  => "str",
     )
     # accessor is a method call with arg: $_->price_with_discount($discount)
-    ->order(
+    ->order_by(
         [ price_with_discount => $discount ] => [ "num", "desc" ],
         name                                 => [ str => sub { uc($_) } ],
         "id",
@@ -712,9 +611,9 @@ When the first comparison is a tie, the subsequent ones are used.
 
 Almost all of the methods are context sensitive, i.e. they return a
 list in list context and an arrayref in scalar context, just like
-autobox::Core.
+L<autobox::Core>.
 
-Beware: you might be in list context when you need an arrayref.
+B<Beware>: I<you might be in list context when you need an arrayref.>
 
 When in doubt, assume they work like C<map> and C<grep> (i.e. return a
 list), and convert the return value to references where you might have
@@ -980,11 +879,11 @@ sub order {
 
 
 
-=head2 @array->group($value_subref = object) : %key_value | %$key_value
+=head2 @array->group($value_subref = item) : %key_value | %$key_value
 
 Group the @array items into a hashref with the items as keys.
 
-The default $value_subref puts each object in the list as the hash
+The default $value_subref puts each item in the list as the hash
 value. If the key is repeated, the value is overwritten with the last
 object.
 
@@ -1082,7 +981,8 @@ sub group_count {
     my $array = shift;
 
     my $value_sub = sub {
-        my $count = shift // 0; return ++$count;
+        my $count = shift // 0;
+        return ++$count;
     };
 
     return __core_group("group_count", $array, $value_sub);
@@ -1112,9 +1012,9 @@ sub group_array {
     my $array = shift;
 
     my $value_sub = sub {
-        my $array = shift // [];
-        push( @$array, $_ );
-        return $array;
+        my $value_array = shift // [];
+        push( @$value_array, $_ );
+        return $value_array;
     };
 
     return __core_group("group_array", $array, $value_sub);
